package com.smartgwt.sample.client;

import com.google.gwt.core.client.EntryPoint;
import com.smartgwt.client.data.Criteria;
import com.smartgwt.client.data.DSRequest;
import com.smartgwt.client.data.DataSource;
import com.smartgwt.client.types.ImageStyle;
import com.smartgwt.client.widgets.Img;
import com.smartgwt.client.widgets.form.DynamicForm;
import com.smartgwt.client.widgets.form.events.ItemKeyPressEvent;
import com.smartgwt.client.widgets.form.events.ItemKeyPressHandler;
import com.smartgwt.client.widgets.form.fields.ButtonItem;
import com.smartgwt.client.widgets.form.fields.TextItem;
import com.smartgwt.client.widgets.form.fields.events.ClickHandler;
import com.smartgwt.client.widgets.layout.VLayout;

/**
 * Entry point classes define <code>onModuleLoad()</code>.
 */
public class SmartGwtR implements EntryPoint {

	public void onModuleLoad() {
		ChartPane chartPane = new ChartPane();
        chartPane.draw();
	}

	class ChartPane extends VLayout {
    	private RChart rChart;
    	private DynamicForm form;
    	private Criteria criteria;
    	
    	public ChartPane () {
    		this.form = new DynamicForm();
    		this.form.setWidth(200);
    		this.form.setWrapItemTitles(false);
    		this.form.setAutoFocus(true);
    		this.form.setNumCols(3);
    		TextItem text = new TextItem();
    		text.setName("stockSymbol");
    		text.setTitle("Stock Symbol");
    		text.setDefaultValue("YHOO");
    		ButtonItem button = new ButtonItem();
    		button.setTitle("Chart");
    		button.setStartRow(false);
    		button.addClickHandler(new ClickHandler() {
				@Override
				public void onClick(
						com.smartgwt.client.widgets.form.fields.events.ClickEvent event) {
					updateChart();
				}
    		});
    		this.form.setItems(text, button);
    		
    		this.form.addItemKeyPressHandler(new ItemKeyPressHandler() {
				@Override
				public void onItemKeyPress(ItemKeyPressEvent event) {
					if (event.getKeyName().equalsIgnoreCase("Enter")) {
						updateChart();
					}
				}
    		});
    		
    		this.rChart = new RChart();
    		this.criteria = new Criteria();
    		this.criteria.addCriteria("name", "stockChart");
    		this.criteria.addCriteria("stockSymbol", this.form.getValueAsString("stockSymbol"));
    		this.criteria.addCriteria("width", "900");
    		this.criteria.addCriteria("height", "360");
    		this.rChart.setCriteria(criteria);
    		
    		this.addMembers(form, rChart);
    	}
    	
    	private void updateChart () {
    		this.criteria.addCriteria("stockSymbol", this.form.getValueAsString("stockSymbol"));
    		this.rChart.setCriteria(criteria);
    	}
    }
    
    class RChart extends Img {
    	Criteria criteria = new Criteria();
    	
    	public RChart () {
    		this.setImageType(ImageStyle.NORMAL);
    		this.setName("stockChart");
    		this.setWidth("900");
    		this.setHeight("360");
    		this.doSetSrc();
    		this.resetSrc();
    	}
    	
    	private void doSetSrc() {
    		DataSource ds = DataSource.get("RChartDS");
    		DSRequest properties = new DSRequest();
    		properties.setOperationId("getChart");
    		this.setSrc(ds.getFetchDataURL(this.getCriteria(), properties));
    	}
    	private void setCriteria(Criteria criteria) {
    		this.criteria = criteria;
    		this.doSetSrc();
    		this.resetSrc();
    	}
    	private Criteria getCriteria() {
    		return this.criteria;
    	}
    }
}
